@@ -3,7 +3,7 @@ package Mail::Milter::Authentication;
 use strict;
 use warnings;
 use base 'Net::Server::PreFork';
-our $VERSION = '2.20180430'; # VERSION
+our $VERSION = '2.20180509'; # VERSION
 
 
 use English qw{ -no_match_vars };
@@ -275,8 +275,7 @@ sub child_is_talking_hook {
 
     eval {
         $raw_request = <$socket>;
-        return if ! $raw_request;
-        $request = decode_json( $raw_request );
+        $request = decode_json( $raw_request ) if defined $raw_request;
     };
     if ( my $error = $@ ) {
         warn "Error $error reading from child";
@@ -284,6 +283,8 @@ sub child_is_talking_hook {
     }
     else {
 
+        return if ! defined $raw_request;
+
         if ( ! $request ) {
             warn "Ignoring Invalid child request: $raw_request;";
             return;
@@ -1047,7 +1048,7 @@ Mail::Milter::Authentication - A Perl Mail Authentication Milter
 
 =head1 VERSION
 
-version 2.20180430
+version 2.20180509
 
 =head1 SYNOPSIS
 
