@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::DMARC;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20180430'; # VERSION
+our $VERSION = '2.20180509'; # VERSION
 
 use Data::Dumper;
 use English qw{ -no_match_vars };
@@ -81,6 +81,7 @@ sub pre_loop_setup {
         $dmarc->config( $config->{ 'config_file' } );
     }
     my $psl = eval { $dmarc->get_public_suffix_list(); };
+    if ( my $error = $@ ) { die $error if $error =~ /Timeout/; }
     if ( $psl ) {
         $self->{'thischild'}->loginfo( 'DMARC Preloaded PSL' );
     }
@@ -140,6 +141,7 @@ sub _process_dmarc_for {
         if ( my $error = $@ ) {
             if ( $error =~ /invalid envelope_from at / ) {
                 $self->log_error( 'DMARC Invalid envelope from <' . $env_domain_from . '>' );
+                die $error if $error =~ /Timeout/; # Should never happen
                 $self->metric_count( 'dmarc_total', { 'result' => 'permerror' } );
                 my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'dmarc' )->safe_set_value( 'permerror' );
                 $header->add_child( Mail::AuthenticationResults::Header::Comment->new()->safe_set_value( 'envelope from invalid' ) );
@@ -148,6 +150,7 @@ sub _process_dmarc_for {
             }
             else {
                 $self->log_error( 'DMARC Mail From Error for <' . $env_domain_from . '> ' . $error );
+                die $error if $error =~ /Timeout/;
                 $self->metric_count( 'dmarc_total', { 'result' => 'temperror' } );
                 my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'dmarc' )->safe_set_value( 'temperror' );
                 $header->add_child( Mail::AuthenticationResults::Header::Comment->new()->safe_set_value( 'envelope from failed' ) );
@@ -164,12 +167,14 @@ sub _process_dmarc_for {
     };
     if ( my $error = $@ ) {
         $self->log_error( 'DMARC Rcpt To Error ' . $error );
+        die $error if $error =~ /Timeout/;
     }
 
     # Add the From Header
     eval { $dmarc->header_from( $header_domain ) };
     if ( my $error = $@ ) {
         $self->log_error( 'DMARC Header From Error ' . $error );
+        die $error if $error =~ /Timeout/;
         $self->metric_count( 'dmarc_total', { 'result' => 'permerror' } );
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'dmarc' )->safe_set_value( 'permerror' );
         $header->add_child( Mail::AuthenticationResults::Header::Comment->new()->safe_set_value( 'from header invalid' ) );
@@ -194,6 +199,7 @@ sub _process_dmarc_for {
     };
     if ( my $error = $@ ) {
         $self->log_error( 'DMARC SPF Error: ' . $error );
+        die $error if $error =~ /Timeout/;
         $dmarc->{'spf'} = [];
     }
 
@@ -228,6 +234,7 @@ sub _process_dmarc_for {
 
     my $dmarc_disposition = eval { $dmarc_result->disposition() };
     if ( my $error = $@ ) {
+        die $error if $error =~ /Timeout/;
         if ( $dmarc_code ne 'pass' ) {
             $self->log_error( 'DMARCPolicyError ' . $error );
         }
@@ -235,6 +242,7 @@ sub _process_dmarc_for {
     $self->dbgout( 'DMARCDisposition', $dmarc_disposition, LOG_INFO );
 
     my $dmarc_policy = eval{ $dmarc_result->published()->p(); };
+    if ( my $error = $@ ) { die $error if $error =~ /Timeout/; }
     # If we didn't get a result, set to none.
     $dmarc_policy = 'none' if ! $dmarc_policy;
     $self->dbgout( 'DMARCPolicy', $dmarc_policy, LOG_INFO );
@@ -310,6 +318,7 @@ sub _process_dmarc_for {
 
     # Try as best we can to save a report, but don't stress if it fails.
     my $rua = eval { $dmarc_result->published()->rua(); };
+    if ( my $error = $@ ) { die $error if $error =~ /Timeout/; }
     if ($rua) {
         if ( ! $config->{'no_report'} ) {
             if ( ! $self->{'skip_report'} ) {
@@ -319,6 +328,7 @@ sub _process_dmarc_for {
                 };
                 if ( my $error = $@ ) {
                     $self->log_error( 'DMARC Report Error ' . $error );
+                    die $error if $error =~ /Timeout/;
                 }
             }
             else {
@@ -360,6 +370,7 @@ sub get_dmarc_object {
     };
     if ( my $error = $@ ) {
         $self->log_error( 'DMARC IP Error ' . $error );
+        die $error if $error =~ /Timeout/;
         my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'dmarc' )->safe_set_value( 'permerror' );
         $self->add_auth_header( $header );
         $self->metric_count( 'dmarc_total', { 'result' => 'permerror' } );
@@ -487,16 +498,16 @@ sub eom_callback {
 
     my $env_from = $self->{ 'env_from' };
     my $env_domains_from = $self->get_domains_from($env_from);
-    $env_domains_from = [''] if ! $env_domains_from;
+    $env_domains_from = [''] if ! @$env_domains_from;
 
     my $from_headers = $self->{ 'from_headers' };
 
     # Build a list of all from header domains used
     my @header_domains;
     foreach my $from_header ( @$from_headers ) {
-    my $from_header_header_domains = $self->get_domains_from( $from_header );
+        my $from_header_header_domains = $self->get_domains_from( $from_header );
         foreach my $header_domain ( @$from_header_header_domains ) {
-        push @header_domains, $header_domain;
+            push @header_domains, $header_domain;
         }
     }
 
@@ -511,12 +522,14 @@ sub eom_callback {
             if ( my $error = $@ ) {
                 if ( $error =~ /invalid header_from at / ) {
                     $self->log_error( 'DMARC Error invalid header_from <' . $self->{'from_header'} . '>' );
+                    die $error if $error =~ /Timeout/; # should never happen
                     my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'dmarc' )->safe_set_value( 'permerror' );
                     $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'header.from' )->safe_set_value( $header_domain ) );
                     $self->_add_dmarc_header( $header );
                 }
                 else {
                     $self->log_error( 'DMARC Error ' . $error );
+                    die $error if $error =~ /Timeout/;
                     my $header = Mail::AuthenticationResults::Header::Entry->new()->set_key( 'dmarc' )->safe_set_value( 'temperror' );
                     $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'header.from' )->safe_set_value( $header_domain ) );
                     $self->_add_dmarc_header( $header );
@@ -626,7 +639,7 @@ Mail::Milter::Authentication::Handler::DMARC
 
 =head1 VERSION
 
-version 2.20180430
+version 2.20180509
 
 =head1 DESCRIPTION
 
