@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::ReturnOK;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20180430'; # VERSION
+our $VERSION = '2.20180509'; # VERSION
 
 use Net::DNS;
 use Sys::Syslog qw{:standard :macros};
@@ -46,6 +46,7 @@ sub _check_address {
         my $dmarc_object = $dmarc_handler->get_dmarc_object();
         if ( $domain ) {
             my $org_domain = eval{ $dmarc_object->get_organizational_domain( $domain ); };
+            if ( my $error = $@ ) { die $error if $error =~ /Timeout/; }
             if ( $org_domain eq $domain ) {
                 $self->{ 'metrics' }->{ $type . '_is_org_domain' } = 'yes';
                 push @{ $self->{ 'details' } }, Mail::AuthenticationResults::Header::SubEntry->new()->set_key( $type . '_is_org_domain' )->safe_set_value( 'yes' );
@@ -107,6 +108,7 @@ sub _check_domain {
     };
     if ( my $error = $@ ) {
         $self->log_error( "ReturnOK: Domain lookup fatal error $error for $domain" );
+        die $error if $error =~ /Timeout/;
         push @details, Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'mx.error' )->safe_set_value( 'lookup_error' );
     }
 
@@ -135,6 +137,7 @@ sub _check_domain {
         };
         if ( my $error = $@ ) {
             $self->log_error( "ReturnOK: Domain lookup fatal error $error for $domain" );
+            die $error if $error =~ /Timeout/;
             push @details, Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'a.error' )->safe_set_value( 'lookup_error' );
         }
 
@@ -161,6 +164,7 @@ sub _check_domain {
         };
         if ( my $error = $@ ) {
             $self->log_error( "ReturnOK: Domain lookup fatal error $error for $domain" );
+            die $error if $error =~ /Timeout/;
             push @details, Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'aaaa.error' )->safe_set_value( 'lookup_error' );
         }
 
@@ -248,7 +252,7 @@ Mail::Milter::Authentication::Handler::ReturnOK
 
 =head1 VERSION
 
-version 2.20180430
+version 2.20180509
 
 =head1 DESCRIPTION
 
